#!/bin/sh

if [ -z "${FILE_TO_SCAN}" ]; then
    printf "\e[0;31m%-6s\e[m\n" "** ERROR: file to scan is missing. Aborting.."
    exit 1
fi

. ./google_chat.sh

FILE_BASENAME=""
FILE_NAME=""
LOG_FILE=""
JOB_URL=""
CLEANUP=0

if echo "${FILE_TO_SCAN}" | grep -qi "https://"; then
    FILE_BASENAME=$(basename "${FILE_TO_SCAN}")
    FILE_NAME=$FILE_BASENAME

    curl -k "${FILE_TO_SCAN}" -o "${FILE_NAME}"
    CLEANUP=1
elif [ -f "${REP_PATH_CLI}/${FILE_TO_SCAN}" ]; then
    FILE_BASENAME="${FILE_TO_SCAN}"
    FILE_NAME="${REP_PATH_CLI}/${FILE_TO_SCAN}"
else
    printf "\e[0;31m%-6s\e[m\n" "** ERROR: File not found or invalid. Aborting .."
    exit 1
fi

LOG_FILE="${REP_PATH_CLI}/clamav_${FILE_BASENAME}_status.out"

if [ -z "${PKG_NAME}" ]; then
    PKG_NAME="${FILE_BASENAME}"
elif [ -z "${PKG_VER}" ]; then
    PKG_VER="NULL"
fi

if [ "${BUILD_URL}" ]; then
    # we're in jenkins
    JOB_URL="${BUILD_URL}console"
elif [ "${CI_PROJECT_URL}" ] && [ "${CI_JOB_ID}" ]; then
    # we're in gitlab
    JOB_URL="${CI_PROJECT_URL}/-/jobs/${CI_JOB_ID}"
else
    JOB_URL="UNAVAILABLE"
fi

{
    printf "\e[0;33m%-6s\e[m\n" "** INFO: Initiating malware scan of ${PKG_NAME}@${PKG_VER}"

    clamscan --version

    clamscan --infected \
        --suppress-ok-results \
        --scan-archive=yes \
        --recursive "${FILE_NAME}" \
        --log="${LOG_FILE}" \  
           $google_chat_channel

    scan_code=$?

    if [ ${scan_code} -eq 1 ]; then
        google_chat_channel="PSEC"

        printf "\e[0;33m%-6s\e[m\n" "** INFO: Malware was found. Please, see scan summary."
       
        grep -i "found" <"${LOG_FILE}" | cut -d ':' -f 2 | cut -d ' ' -f 2 | while IFS= read -r m; do
            notify "*Malware has been found by ClamAV!* \
                \n- Package name: ${PKG_NAME} \
                \n- Package Version: ${PKG_VER} \
                \n- Finding: ${m} \
                \n- Job URL: ${JOB_URL}"\
                 $google_chat_channe
         done 
         
        scan_code=0
    elif [ ${scan_code} -eq 0 ]; then
        google_chat_channel="MALWARE"

        printf "\e[0;33m%-6s\e[m\n" "** INFO: No malware was found."

        notify "*ClamAV scan activities complete! Summary:* \
            \n- Package name: ${PKG_NAME} \
            \n- Package Version: ${PKG_VER} \
            \n- Job URL: ${JOB_URL}" \
            $google_chat_channel
    
            
    fi
} || {
    google_chat_channel="PSEC"

    printf "\e[0;31m%-6s\e[m\n" "** ERROR: Failed to execute one or more functions of ClamAV! Notifying the Product Security team .."
    notify "*Failed to execute one or more functions of ClamAV!* \
        \n- Package name: ${PKG_NAME} \
        \n- Package Version: ${PKG_VER} \
        \n- Job URL: ${JOB_URL}" \
        $google_chat_channel
    exit 1
}

chmod -R 444 "${LOG_FILE}"

if [ "$CLEANUP" -eq 1 ]; then
    rm -f "${FILE_NAME}"
fi

exit ${scan_code}
