#!/bin/sh

usage() {
    printf "\n"
    printf "Usage: $(basename $0) -c -r -f path_to_file -n package_name -v package_version -p prev_package_version\n"
    printf "\n"
    printf "\t-c\t for ClamAV scanning\n"
    printf "\t-f\t file to be scanned\n"
    printf "\t-r\t for RL Secure scanning\n"
    printf "\t-n\t package name\n"
    printf "\t-v\t package version\n"
    printf "\t-p\t previous package version for report diff (RL Secure)\n"
}

CLAMAV_SCAN=0
FILE_TO_SCAN=""
RL_SCAN=0
PKG_NAME=""
PKG_VER=""
RL_PREV_PKG_VER=""

while getopts "cf:rn:v:p:" flag; do
    case "${flag}" in
        c)
            CLAMAV_SCAN=1 ;;
        f)
            FILE_TO_SCAN=${OPTARG} ;;
        r)
            RL_SCAN=1 ;;
        n)
            PKG_NAME=${OPTARG} ;;
        v)
            PKG_VER=${OPTARG} ;;
        p)
            RL_PREV_PKG_VER=${OPTARG} ;;
        *)
            usage
            exit 1 ;;
    esac
done

if [ $((CLAMAV_SCAN+RL_SCAN)) -eq 0 ]; then
    printf "\e[0;31m%-6s\e[m\n" "** ERROR: no scan was selected. See usage for instructions\n"
    usage
    exit 1
fi

if [ -z "${FILE_TO_SCAN}" ]; then
    printf "\e[0;31m%-6s\e[m\n" "** ERROR: the required argument for option '-f' is missing\n"
    usage
    exit 1
fi

if [ "${CLAMAV_SCAN}" -eq 1 ]; then
    export FILE_TO_SCAN PKG_NAME PKG_VER RL_PREV_PKG_VER 
    sh clamav.sh
    SCAN_EXIT_CODE=$?
fi

if [ "${RL_SCAN}" -eq 1 ]; then
    export FILE_TO_SCAN PKG_NAME PKG_VER RL_PREV_PKG_VER
    sh rl_secure.sh 
    SCAN_EXIT_CODE=$?
fi

exit "${SCAN_EXIT_CODE}"